#! /bin/sh

#BEGIN DEPEND------------------------------------------------------------------
INPUT_MODULES='src/lib/perl5/COD/CIF/Data/CIF2COD.pm'
#END DEPEND--------------------------------------------------------------------

perl <<'END_SCRIPT'
#------------------------------------------------------------------------------
#$Author: antanas $
#$Date: 2019-12-17 15:51:32 +0200 (Tue, 17 Dec 2019) $ 
#$Revision: 7615 $
#$URL: svn://www.crystallography.net/cod-tools/tags/v3.4.0/tests/shtests/get_cod_status_from_issue_severity_002.sh $
#------------------------------------------------------------------------------
#*
#* Unit test for the COD::CIF::Data::CIF2COD::get_cod_status_from_issue_severity
#* subroutine. Tests the way the subroutine behaves when the input data block
#* contains the '_cod_entry_issue_severity' data item with various flag values.
#**

use strict;
use warnings;

use COD::CIF::Data::CIF2COD;

my $data_block =
{
    'name'   => 'cod_retracted_entry_issues',
    'tags'   => [
                  '_cod_entry_issue_id',
                  '_cod_entry_issue_severity'
                ],
    'loops'  => [
                  [ '_cod_entry_issue_id', '_cod_entry_issue_severity' ],
                ],
    'inloop' => {
                  '_cod_entry_issue_id' => 0,
                  '_cod_entry_issue_severity' => 0,
                },
    'values' => {
                  '_cod_entry_issue_id' => [
                    '1', '2', '3', '4'
                  ],
                  '_cod_entry_issue_severity' => [
                    'note', 'warning', 'error', 'retraction'
                  ],
                },
    'precisions' => {},
    'types'  => { 
                  '_cod_entry_issue_id' => [
                    'INT', 'INT', 'INT', 'INT'
                  ],
                  '_cod_entry_issue_severity' => [
                    'UQSTRING', 'UQSTRING', 'UQSTRING', 'UQSTRING'
                  ]
                }
};

my $value = COD::CIF::Data::CIF2COD::get_cod_status_from_issue_severity($data_block);
if (defined $value) {
    print 'Data block \'' . $data_block->{'name'} . "' has the '$value' status." . "\n";
} else {
    print 'Data block \'' . $data_block->{'name'} . '\' has an undefined status.' . "\n";
}

$data_block->{'values'}{'_cod_entry_issue_severity'}[3] = 'note';
$value = COD::CIF::Data::CIF2COD::get_cod_status_from_issue_severity($data_block);
if (defined $value) {
    print 'Data block \'' . $data_block->{'name'} . "' has the '$value' status." . "\n";
} else {
    print 'Data block \'' . $data_block->{'name'} . '\' has an undefined status.' . "\n";
}

$data_block->{'values'}{'_cod_entry_issue_severity'}[2] = 'note';
$value = COD::CIF::Data::CIF2COD::get_cod_status_from_issue_severity($data_block);
if (defined $value) {
    print 'Data block \'' . $data_block->{'name'} . "' has the '$value' status." . "\n";
} else {
    print 'Data block \'' . $data_block->{'name'} . '\' has an undefined status.' . "\n";
}

# Data item contains a value that is allowed by the DDL1 dictionary,
# but not by the SQL schema 
$data_block->{'values'}{'_cod_entry_issue_severity'}[1] = 'note';
$value = COD::CIF::Data::CIF2COD::get_cod_status_from_issue_severity($data_block);
if (defined $value) {
    print 'Data block \'' . $data_block->{'name'} . "' has the '$value' status." . "\n";
} else {
    print 'Data block \'' . $data_block->{'name'} . '\' has an undefined status.' . "\n";
}

# Data item contains a value that is allowed neither by the DDL1 dictionary,
# nor by the SQL schema
$data_block->{'values'}{'_cod_entry_issue_severity'}[0] = 'unknown';
$data_block->{'values'}{'_cod_entry_issue_severity'}[1] = 'unknown';
$data_block->{'values'}{'_cod_entry_issue_severity'}[2] = 'unknown';
$data_block->{'values'}{'_cod_entry_issue_severity'}[3] = 'unknown';
$value = COD::CIF::Data::CIF2COD::get_cod_status_from_issue_severity($data_block);
if (defined $value) {
    print 'Data block \'' . $data_block->{'name'} . "' has the '$value' status." . "\n";
} else {
    print 'Data block \'' . $data_block->{'name'} . '\' has an undefined status.' . "\n";
}

END_SCRIPT
